@@ -62,7 +62,7 @@ class DRACOONGroups:
         if self.raise_on_err:
             raise_on_err = True
 
-        payload = group.dict(exclude_unset=True)
+        payload = group.model_dump(exclude_unset=True)
 
         if not await self.dracoon.test_connection() and self.dracoon.connection:
             await self.dracoon.connect(OAuth2ConnectionType.refresh_token)
@@ -101,7 +101,7 @@ class DRACOONGroups:
         
         if filter: filter = urllib.parse.quote(filter)
 
-        api_url = self.api_url + f'/?offset={offset}'
+        api_url = self.api_url + f'?offset={offset}'
         if filter != None: api_url += f'&filter={filter}' 
         if limit != None: api_url += f'&limit={str(limit)}' 
         if sort != None: api_url += f'&sort={sort}' 
@@ -154,7 +154,7 @@ class DRACOONGroups:
 
         api_url = self.api_url + f'/{str(group_id)}'
 
-        payload = group_update.dict(exclude_unset=True)
+        payload = group_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -211,7 +211,7 @@ class DRACOONGroups:
         
         if filter: filter = urllib.parse.quote(filter)
 
-        api_url = self.api_url + f'/{group_id}/users/?offset={str(offset)}'
+        api_url = self.api_url + f'/{group_id}/users?offset={str(offset)}'
         if filter != None: api_url += f'&filter={filter}' 
         if limit != None: api_url += f'&limit={str(limit)}' 
         if sort != None: api_url += f'&sort={sort}' 
