@@ -17,10 +17,10 @@ class UserInfo(BaseModel):
     id: int
     userType: UserType
     avatarUuid: str
-    userName: Optional[str]
-    firstName: Optional[str]
-    lastName: Optional[str]
-    email: Optional[str]
+    userName: Optional[str] = None
+    firstName: Optional[str] = None
+    lastName: Optional[str] = None
+    email: Optional[str] = None
 
 
 class Group(BaseModel):
@@ -29,10 +29,10 @@ class Group(BaseModel):
     createdAt: datetime
     createdBy: UserInfo
     cntUsers: int
-    updatedAt: Optional[datetime]
-    updatedBy: Optional[UserInfo]
-    expireAt: Optional[datetime]
-    groupRoles:Optional[RoleList]
+    updatedAt: Optional[datetime] = None
+    updatedBy: Optional[UserInfo] = None
+    expireAt: Optional[datetime] = None
+    groupRoles:Optional[RoleList] = None
 
 class GroupList(BaseModel):
     range: Range
@@ -50,7 +50,7 @@ class LastAdminGroupRoom(BaseModel):
     id: int
     name: str
     parentPath: str
-    parentId: Optional[int]
+    parentId: Optional[int] = None
 
 class LastAdminGroupRoomList(BaseModel):
     items: List[LastAdminGroupRoom]
