@@ -26,13 +26,13 @@ import urllib.parse
 import httpx
 from tenacity import retry
 
-from dracoon.crypto import FileEncryptionCipher, encrypt_bytes, encrypt_file_key, create_file_key
+from dracoon.crypto import FileEncryptionCipher, decrypt_file_key, encrypt_bytes, encrypt_file_key, create_file_key, encrypt_file_key_public
 from dracoon.crypto.models import FileKey, PlainUserKeyPairContainer, UserKeyPairContainer
 from dracoon.groups.models import Expiration
 from dracoon.client import DRACOONClient, OAuth2ConnectionType, RETRY_CONFIG
 from dracoon.errors import (InvalidClientError, ClientDisconnectedError, InvalidFileError, InvalidArgumentError)
 from dracoon.uploads.models import UploadChannelResponse
-from .models import (Callback, CompleteS3Upload, CompleteUpload, ConfigRoom, CreateFolder, CreateRoom, CreateUploadChannel, EncryptRoom, 
+from .models import (Callback, CompleteS3Upload, CompleteUpload, ConfigRoom, CreateFolder, CreateRoom, CreateUploadChannel, EncryptRoom, FileVersionList, 
                      GetS3Urls, LogEventList, MissingKeysResponse, Node, NodeItem, Permissions, ProcessRoomPendingUsers, S3Part, 
                      SetFileKeys, SetFileKeysItem, TransferNode, CommentNode, RestoreNode, UpdateFile, UpdateFiles, 
                      UpdateFolder, UpdateRoom, UpdateRoomGroupItem, UpdateRoomGroups, UpdateRoomHooks, 
@@ -48,6 +48,7 @@ CHUNK_SIZE = 33554432
 MIN_CHUNK_SIZE = 5242880
 MAX_CHUNKS = 9999
 POLL_WAIT = 0.1
+FILE_KEY_LIMIT = 50
 
 class DRACOONNodes:
 
@@ -106,7 +107,7 @@ class DRACOONNodes:
     @retry(**RETRY_CONFIG)
     async def create_upload_channel(self, upload_channel: CreateUploadChannel, raise_on_err: bool = False) -> CreateFileUploadResponse:
         """ create an upload channel to upload (S3 direct or proxy) """
-        payload = upload_channel.dict(exclude_unset=True)
+        payload = upload_channel.model_dump(exclude_unset=True)
 
         if not await self.dracoon.test_connection() and self.dracoon.connection:
             await self.dracoon.connect(OAuth2ConnectionType.refresh_token)
@@ -228,7 +229,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/files/uploads/{upload_id}/s3'
 
-        payload = upload.dict(exclude_unset=True)
+        payload = upload.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -283,7 +284,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/files/uploads/{upload_id}/s3_urls'
 
-        payload = upload.dict(exclude_unset=True)
+        payload = upload.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.post(url=api_url, json=payload)
@@ -299,7 +300,7 @@ class DRACOONNodes:
     
     @retry(**RETRY_CONFIG)
     async def upload_unencrypted(self, file_path: str, upload_channel: CreateFileUploadResponse, keep_shares: bool = False, 
-                                    file_name: str = None, resolution_strategy: str = 'autorename', chunksize: int = CHUNK_SIZE, 
+                                    file_name: str = None, resolution_strategy: str = 'autorename', raise_on_err: bool = False, chunksize: int = CHUNK_SIZE, 
                                     callback_fn: Callback  = None
                                     ) -> Node:
         if self.raise_on_err:
@@ -477,6 +478,31 @@ class DRACOONNodes:
                                                    resolution_strategy=resolution_strategy, file_key=file_key)
         
         node = await self.complete_upload(upload_channel=upload_channel, payload=complete_upload, raise_on_err=raise_on_err)
+
+        missing_keys = await self.get_missing_file_keys(file_id=node.id, limit=FILE_KEY_LIMIT)
+
+        if missing_keys.range.total > 0:
+            keys = self.make_set_file_keys(file_key_list=[])
+
+            for key in missing_keys.items:
+                # get file key
+                for file_item in missing_keys.files:
+                    if key.fileId == file_item.id:
+                        file_key = file_item.fileKeyContainer
+                        plain_file_key = decrypt_file_key(file_key=file_key, keypair=plain_keypair)
+
+                # add requests per user 
+                for user in missing_keys.users:
+                    if key.userId == user.id:
+                        public_key = user.publicKeyContainer
+
+                user_file_key = encrypt_file_key_public(plain_file_key=plain_file_key, public_key=public_key)
+
+                file_key_item = self.make_set_file_key_item(file_id=key.fileId, user_id=key.userId, file_key=user_file_key)
+
+                keys.items.append(file_key_item)
+                    
+            await self.set_file_keys(file_keys=keys)
              
         return node
     
@@ -503,7 +529,7 @@ class DRACOONNodes:
         api_url = self.dracoon.base_url + self.dracoon.api_base_url + f'/uploads/{upload_channel.token}'
         
         try:
-            res = await self.dracoon.http.put(api_url, json=payload.dict(exclude_unset=True))
+            res = await self.dracoon.http.put(api_url, json=payload.model_dump(exclude_unset=True))
             res.raise_for_status()
         except httpx.RequestError as e:
             await self.dracoon.http.delete(upload_channel.uploadUrl)
@@ -804,6 +830,33 @@ class DRACOONNodes:
         while True:
             upload_status = await self.check_s3_upload(upload_id=upload_channel.uploadId, raise_on_err=raise_on_err)
             if upload_status.status == S3Status.done.value:
+                missing_keys = await self.get_missing_file_keys(file_id=upload_status.node.id, limit=FILE_KEY_LIMIT)
+
+                if missing_keys.range.total == 0:
+                    break
+
+                keys = self.make_set_file_keys(file_key_list=[])
+
+                for key in missing_keys.items:
+                    # get file key
+                    for file_item in missing_keys.files:
+                        if key.fileId == file_item.id:
+                            file_key = file_item.fileKeyContainer
+                            plain_file_key = decrypt_file_key(file_key=file_key, keypair=plain_keypair)
+
+                    # add requests per user 
+                    for user in missing_keys.users:
+                        if key.userId == user.id:
+                            public_key = user.publicKeyContainer
+
+                    user_file_key = encrypt_file_key_public(plain_file_key=plain_file_key, public_key=public_key)
+
+                    file_key_item = self.make_set_file_key_item(file_id=key.fileId, user_id=key.userId, file_key=user_file_key)
+
+                    keys.items.append(file_key_item)
+                
+                await self.set_file_keys(file_keys=keys)
+
                 break
             if upload_status.status == S3Status.error.value:
                 break
@@ -848,7 +901,7 @@ class DRACOONNodes:
         if filter: filter = urllib.parse.quote(filter)
 
         api_url = self.api_url + \
-            f'/?offset={offset}&parent_id={str(parent_id)}&room_manager={str(room_manager).lower()}'
+            f'?offset={offset}&parent_id={str(parent_id)}&room_manager={str(room_manager).lower()}'
         if filter != None:
             api_url += f'&filter={filter}'
         if limit != None:
@@ -953,7 +1006,7 @@ class DRACOONNodes:
             raise_on_err = True
 
         api_url = self.api_url + \
-            f'/{str(node_id)}/comments/?offset={str(offset)}'
+            f'/{str(node_id)}/comments?offset={str(offset)}'
 
         try:
             res = await self.dracoon.http.get(api_url)
@@ -971,7 +1024,7 @@ class DRACOONNodes:
     @retry(**RETRY_CONFIG)
     async def add_node_comment(self, node_id: int, comment: CommentNode, raise_on_err: bool = False) -> Comment:
         """ add a comment to a node """
-        payload = comment.dict(exclude_unset=True)
+        payload = comment.model_dump(exclude_unset=True)
 
         if self.raise_on_err:
             raise_on_err = True
@@ -1004,7 +1057,7 @@ class DRACOONNodes:
     @retry(**RETRY_CONFIG)
     async def copy_nodes(self, target_id: int, copy_node: TransferNode, raise_on_err: bool = False) -> Node:
         """ copy node(s) to given target id """
-        payload = copy_node.dict(exclude_unset=True)
+        payload = copy_node.model_dump(exclude_unset=True)
 
         if not await self.dracoon.test_connection() and self.dracoon.connection:
             await self.dracoon.connect(OAuth2ConnectionType.refresh_token)
@@ -1063,7 +1116,7 @@ class DRACOONNodes:
         if filter: filter = urllib.parse.quote(filter)
 
         api_url = self.api_url + \
-            f'/{str(parent_id)}/deleted_nodes/?offset={offset}'
+            f'/{str(parent_id)}/deleted_nodes?offset={offset}'
 
         if filter != None:
             api_url += f'&filter={filter}'
@@ -1186,7 +1239,7 @@ class DRACOONNodes:
     @retry(**RETRY_CONFIG)
     async def move_nodes(self, target_id: int, move_node: TransferNode, raise_on_err: bool = False) -> Node:
         """ move node(s) to target node (by id) """
-        payload = move_node.dict(exclude_unset=True)
+        payload = move_node.model_dump(exclude_unset=True)
 
         if not await self.dracoon.test_connection() and self.dracoon.connection:
             await self.dracoon.connect(OAuth2ConnectionType.refresh_token)
@@ -1287,7 +1340,7 @@ class DRACOONNodes:
     @retry(**RETRY_CONFIG)
     async def restore_nodes(self, restore: RestoreNode, raise_on_err: bool = False) -> None:
         """ restore a list of nodes from recycle bin """
-        payload = restore.dict(exclude_unset=True)
+        payload = restore.model_dump(exclude_unset=True)
 
         if not await self.dracoon.test_connection() and self.dracoon.connection:
             await self.dracoon.connect(OAuth2ConnectionType.refresh_token)
@@ -1333,7 +1386,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/files/{str(file_id)}'
 
-        payload = file_update.dict(exclude_unset=True)
+        payload = file_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -1359,7 +1412,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/files'
 
-        payload = files_update.dict(exclude_unset=True)
+        payload = files_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -1436,7 +1489,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/files/{str(file_id)}/user_file_key'
 
-        if version: api_url += f'/?version={version}'
+        if version: api_url += f'?version={version}'
 
         try:
             res = await self.dracoon.http.get(api_url)
@@ -1453,7 +1506,7 @@ class DRACOONNodes:
     @retry(**RETRY_CONFIG)
     async def set_file_keys(self, file_keys: SetFileKeys, raise_on_err: bool = False) -> None:
         """ set file keys for nodes """
-        payload = file_keys.dict(exclude_unset=True)
+        payload = file_keys.model_dump(exclude_unset=True)
 
         if self.raise_on_err:
             raise_on_err = True
@@ -1492,7 +1545,7 @@ class DRACOONNodes:
         })
     
     @retry(**RETRY_CONFIG)
-    async def get_file_versions(self, reference_id: int, raise_on_err: bool = False):
+    async def get_file_versions(self, reference_id: int, raise_on_err: bool = False) -> FileVersionList:
         """ get all file versions (including deleted nodes) for given reference id """
         
         if not await self.dracoon.test_connection() and self.dracoon.connection:
@@ -1513,7 +1566,7 @@ class DRACOONNodes:
             await self.dracoon.handle_http_error(err=e, raise_on_err=raise_on_err)
         
         self.logger.info("Retrieved node.")
-        return Node(**res.json())
+        return FileVersionList(**res.json())
 
     @retry(**RETRY_CONFIG)
     async def create_folder(self, folder: CreateFolder, raise_on_err: bool = False) -> Node:
@@ -1526,7 +1579,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/folders'
 
-        payload = folder.dict(exclude_unset=True)
+        payload = folder.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.post(url=api_url, json=payload)
@@ -1576,7 +1629,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/folders/{str(node_id)}'
 
-        payload = folder_update.dict(exclude_unset=True)
+        payload = folder_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -1600,7 +1653,7 @@ class DRACOONNodes:
         if self.raise_on_err:
             raise_on_err = True
 
-        api_url = self.api_url + f'/missingFileKeys/?offset={str(offset)}'
+        api_url = self.api_url + f'/missingFileKeys?offset={str(offset)}'
 
         if file_id != None:
             api_url += f'&file_id={str(file_id)}'
@@ -1637,7 +1690,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/rooms'
 
-        payload = room.dict(exclude_unset=True)
+        payload = room.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.post(url=api_url, json=payload)
@@ -1663,7 +1716,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/rooms/{str(node_id)}'
 
-        payload = room_update.dict(exclude_unset=True)
+        payload = room_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -1727,7 +1780,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/rooms/{str(node_id)}/config'
 
-        payload = config_update.dict(exclude_unset=True)
+        payload = config_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -1813,7 +1866,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/rooms/{str(room_id)}/encrypt'
         
-        payload = encrypt_room.dict(exclude_unset=True)
+        payload = encrypt_room.model_dump(exclude_unset=True)
             
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -1837,7 +1890,7 @@ class DRACOONNodes:
             raise_on_err = True
 
         api_url = self.api_url + \
-            f'/rooms/{str(room_id)}/groups/?offset={str(offset)}'
+            f'/rooms/{str(room_id)}/groups?offset={str(offset)}'
         
         if filter: filter = urllib.parse.quote(filter)
 
@@ -1872,7 +1925,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/rooms/{str(room_id)}/groups'
 
-        payload = groups_update.dict(exclude_unset=True)
+        payload = groups_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -1926,7 +1979,7 @@ class DRACOONNodes:
         if filter: filter = urllib.parse.quote(filter)
 
         api_url = self.api_url + \
-            f'/rooms/{str(room_id)}/users/?offset={str(offset)}'
+            f'/rooms/{str(room_id)}/users?offset={str(offset)}'
 
         if filter != None:
             api_url += f'&filter={filter}'
@@ -1958,7 +2011,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/rooms/{str(room_id)}/users'
 
-        payload = users_update.dict(exclude_unset=True)
+        payload = users_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -2015,7 +2068,7 @@ class DRACOONNodes:
         if filter: filter = urllib.parse.quote(filter)
 
         api_url = self.api_url + \
-            f'/rooms/{str(node_id)}/webhooks/?offset={str(offset)}'
+            f'/rooms/{str(node_id)}/webhooks?offset={str(offset)}'
 
         if filter != None:
             api_url += f'&filter={filter}'
@@ -2048,7 +2101,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/rooms/{str(node_id)}/webhooks'
 
-        payload = hook_update.dict(exclude_unset=True)
+        payload = hook_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -2075,7 +2128,7 @@ class DRACOONNodes:
             
         if filter: filter = urllib.parse.quote(filter)
 
-        api_url = self.api_url + f'/rooms/{room_id}/events/?offset={str(offset)}'
+        api_url = self.api_url + f'/rooms/{room_id}/events?offset={str(offset)}'
 
         if date_start != None: api_url += f'&date_start={date_start}'
         if date_end != None: api_url += f'&date_end={date_end}'
@@ -2108,7 +2161,7 @@ class DRACOONNodes:
         if self.raise_on_err:
             raise_on_err = True
 
-        api_url = self.api_url + f'/rooms/pending/?offset={str(offset)}'
+        api_url = self.api_url + f'/rooms/pending?offset={str(offset)}'
         
         if filter: filter = urllib.parse.quote(filter)
 
@@ -2144,7 +2197,7 @@ class DRACOONNodes:
 
         api_url = self.api_url + f'/rooms/pending'
 
-        payload = pending_update.dict(exclude_unset=True)
+        payload = pending_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -2173,7 +2226,7 @@ class DRACOONNodes:
         if filter: filter = urllib.parse.quote(filter)
 
         api_url = self.api_url + \
-            f'/search/?search_string={search}&offset={str(offset)}&parent_id={str(parent_id)}&depth_level={depth_level}'
+            f'/search?search_string={search}&offset={str(offset)}&parent_id={str(parent_id)}&depth_level={depth_level}'
 
         if filter != None:
             api_url += f'&filter={filter}'
