@@ -81,7 +81,7 @@ class DRACOONShares:
     @retry(**RETRY_CONFIG)
     async def create_share(self, share: CreateShare, raise_on_err: bool = False) -> DownloadShare:
         """ create a new share """
-        payload = share.dict(exclude_unset=True)
+        payload = share.model_dump(exclude_unset=True)
 
         if not await self.dracoon.test_connection() and self.dracoon.connection:
             await self.dracoon.connect(OAuth2ConnectionType.refresh_token)
@@ -104,9 +104,9 @@ class DRACOONShares:
         self.logger.info("Created share.")
         return DownloadShare(**res.json())
 
-    def make_share(self, node_id: int, name: str = None, password: str = None, expiration: str = None, notes: str = None, internal_notes: str = None, 
+    def make_share(self, node_id: int, name: str = None, password: str = None, expiration: Expiration = None, notes: str = None, internal_notes: str = None, 
                    show_creator: bool = None, show_creator_login: bool = None, max_downloads: int = None, keypair: UserKeyPairContainer = None, file_key: FileKey = None, 
-                   language: str = None, sms_recipients: List[str] = None) -> CreateShare:
+                   receiver_language: str = None, sms_recipients: List[str] = None) -> CreateShare:
         
         """ make a share payload required for create_share() """
         share = {
@@ -122,7 +122,7 @@ class DRACOONShares:
         if max_downloads: share["maxDownloads"] = max_downloads
         if keypair: share["keyPair"] = keypair
         if file_key: share["fileKey"] = file_key
-        if language: share["langauge"] = file_key
+        if receiver_language: share["receiverLanguage"] = receiver_language
         if sms_recipients: share["textMessageRecipients"] = sms_recipients
 
         return CreateShare(**share)
@@ -189,7 +189,7 @@ class DRACOONShares:
 
         api_url = self.api_url + f'/downloads'
 
-        payload = shares_update.dict(exclude_unset=True)
+        payload = shares_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -224,7 +224,7 @@ class DRACOONShares:
 
     def make_share_update(self, name: str = None, password: str = None, expiration: str = None, notes: str = None, internal_notes: str = None, 
                    show_creator: bool = None, show_creator_login: bool = None, max_downloads: int = None, keypair: UserKeyPairContainer = None, file_key: FileKey = None, 
-                   language: str = None, sms_recipients: List[str] = None, default_country: str = None,
+                   receiver_language: str = None, sms_recipients: List[str] = None, default_country: str = None,
                    reset_max_downloads: bool = None, reset_password: bool = None) -> UpdateShare:
         
         """ make a share update payload required for update_share() """
@@ -240,7 +240,7 @@ class DRACOONShares:
         if max_downloads: share_update["maxDownloads"] = max_downloads
         if keypair: share_update["keyPair"] = keypair
         if file_key: share_update["fileKey"] = file_key
-        if language: share_update["receiverLangauge"] = language
+        if receiver_language: share_update["receiverLanguage"] = receiver_language
         if default_country: share_update["defaultCountry"] = default_country
         if sms_recipients: share_update["textMessageRecipients"] = sms_recipients
         if reset_max_downloads is not None: share_update["resetMaxDownloads"] = reset_max_downloads
@@ -261,7 +261,7 @@ class DRACOONShares:
 
         api_url = self.api_url + f'/downloads/{str(share_id)}'
 
-        payload = share_update.dict(exclude_unset=True)
+        payload = share_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -303,7 +303,7 @@ class DRACOONShares:
     @retry(**RETRY_CONFIG)
     async def mail_share(self, share_id: int, send_share: SendShare, raise_on_err: bool = False) -> None:
         """ send a specific share via email (by id) """
-        payload = send_share.dict(exclude_unset=True)
+        payload = send_share.model_dump(exclude_unset=True)
 
         if not await self.dracoon.test_connection() and self.dracoon.connection:
             await self.dracoon.connect(OAuth2ConnectionType.refresh_token)
@@ -359,7 +359,7 @@ class DRACOONShares:
     @retry(**RETRY_CONFIG)
     async def create_file_request(self, file_request: CreateFileRequest, raise_on_err: bool = False) -> UploadShare:
         """ create a new file request """
-        payload = file_request.dict(exclude_unset=True)
+        payload = file_request.model_dump(exclude_unset=True)
 
         if not await self.dracoon.test_connection() and self.dracoon.connection:
             await self.dracoon.connect(OAuth2ConnectionType.refresh_token)
@@ -468,7 +468,7 @@ class DRACOONShares:
 
         api_url = self.api_url + f'/uploads'
 
-        payload = file_requests_update.dict(exclude_unset=True)
+        payload = file_requests_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -545,7 +545,7 @@ class DRACOONShares:
 
         api_url = self.api_url + f'/uploads/{str(file_request_id)}'
 
-        payload = file_request_update.dict(exclude_unset=True)
+        payload = file_request_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -587,7 +587,7 @@ class DRACOONShares:
     @retry(**RETRY_CONFIG)
     async def mail_file_request(self, file_request_id: int, send_file_request: SendShare, raise_on_err: bool = False) -> None:
         """ send a specific file request via email (by id) """
-        payload = send_file_request.dict(exclude_unset=True)
+        payload = send_file_request.model_dump(exclude_unset=True)
 
         if not await self.dracoon.test_connection() and self.dracoon.connection:
             await self.dracoon.connect(OAuth2ConnectionType.refresh_token)
