@@ -66,7 +66,7 @@ class DRACOONUser:
             raise_on_err = True
 
         try:
-            api_url = self.api_url + f'/account/?more_info={str(more_info).lower()}'
+            api_url = self.api_url + f'/account?more_info={str(more_info).lower()}'
             res = await self.dracoon.http.get(api_url)
             res.raise_for_status()
         except httpx.RequestError as e:
@@ -89,7 +89,7 @@ class DRACOONUser:
 
         api_url = self.api_url + f'/account'
 
-        payload = account_update.dict(exclude_unset=True)
+        payload = account_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -131,7 +131,7 @@ class DRACOONUser:
             raise_on_err = True
 
         api_url = self.api_url + f'/account/keypair'
-        if version != None: api_url += '/?version=' + version.value
+        if version != None: api_url += '?version=' + version.value
 
         try:
             res = await self.dracoon.http.get(api_url)
@@ -154,7 +154,7 @@ class DRACOONUser:
         if self.raise_on_err:
             raise_on_err = True
         
-        payload = encrypted_keypair.dict(exclude_unset=True)
+        payload = encrypted_keypair.model_dump(exclude_unset=True)
 
         if not await self.dracoon.test_connection() and self.dracoon.connection:
             await self.dracoon.connect(OAuth2ConnectionType.refresh_token)
@@ -184,7 +184,7 @@ class DRACOONUser:
             raise_on_err = True
 
         api_url = self.api_url + f'/account/keypair'
-        if version != None: api_url += '/?version=' + version.value
+        if version != None: api_url += '?version=' + version.value
 
         try:
             res = await self.dracoon.http.delete(api_url)
