@@ -58,7 +58,7 @@ class DRACOONUsers:
     async def create_user(self, user: CreateUser, raise_on_err: bool = False) -> UserData:
         """ creates a new user """
 
-        payload = user.dict(exclude_unset=True)
+        payload = user.model_dump(exclude_unset=True)
 
         if not await self.dracoon.test_connection() and self.dracoon.connection:
             await self.dracoon.connect(OAuth2ConnectionType.refresh_token)
@@ -194,18 +194,21 @@ class DRACOONUsers:
 
     @retry(**RETRY_CONFIG)
     async def get_users(self, offset: int = 0, filter: str = None, limit: int = None, 
-                        sort: str = None, raise_on_err: bool = False) -> UserList:     
+                        sort: str = None, raise_on_err: bool = False, include_attributes: bool = False,
+                        include_roles: bool = False) -> UserList:     
         """ list (all) users """
         if not await self.dracoon.test_connection() and self.dracoon.connection:
             await self.dracoon.connect(OAuth2ConnectionType.refresh_token)
         
         if filter: filter = urllib.parse.quote(filter)
 
-        api_url = self.api_url + f'/?offset={offset}'
+        api_url = self.api_url + f'?offset={offset}'
         if filter != None: api_url += f'&filter={filter}' 
         if limit != None: api_url += f'&limit={str(limit)}' 
-        if sort != None: api_url += f'&sort={sort}' 
-
+        if sort != None: api_url += f'&sort={sort}'
+        if include_attributes: api_url += f'&include_attributes=true'
+        if include_roles: api_url += f'&include_roles=true'
+        
         try:
             res = await self.dracoon.http.get(api_url)
             res.raise_for_status()
@@ -248,7 +251,7 @@ class DRACOONUsers:
 
         api_url = self.api_url + f'/{str(user_id)}'
 
-        payload = user_update.dict(exclude_unset=True)
+        payload = user_update.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -292,7 +295,7 @@ class DRACOONUsers:
         
         if filter: filter = urllib.parse.quote(filter)
 
-        api_url = self.api_url + f'/{user_id}/groups/?offset={str(offset)}'
+        api_url = self.api_url + f'/{user_id}/groups?offset={str(offset)}'
         if filter != None: api_url += f'&filter={filter}' 
         if limit != None: api_url += f'&limit={str(limit)}' 
         if sort != None: api_url += f'&sort={sort}' 
@@ -360,7 +363,7 @@ class DRACOONUsers:
         
         if filter: filter = urllib.parse.quote(filter)
 
-        api_url = self.api_url + f'/{user_id}/userAttributes/?offset={str(offset)}'
+        api_url = self.api_url + f'/{user_id}/userAttributes?offset={str(offset)}'
         if filter != None: api_url += f'&filter={filter}' 
         if limit != None: api_url += f'&limit={str(limit)}' 
         if sort != None: api_url += f'&sort={sort}' 
@@ -399,14 +402,14 @@ class DRACOONUsers:
         return None
 
     @retry(**RETRY_CONFIG)
-    async def update_user_attributes(self, user_id: int, attributes: UpdateUserAttributes, 
-                                     raise_on_err: bool = False) -> UserData:
+    async def update_user_attributes(self, user_id: int, attributes: UpdateUserAttributes,
+                                     raise_on_err: bool = False) -> None:
         """ create / update custom user attribute for a specific user (by id) """
         if not await self.dracoon.test_connection() and self.dracoon.connection:
             await self.dracoon.connect(OAuth2ConnectionType.refresh_token)
 
         api_url = self.api_url + f'/{str(user_id)}/userAttributes'
-        payload = attributes.dict(exclude_unset=True)
+        payload = attributes.model_dump(exclude_unset=True)
 
         try:
             res = await self.dracoon.http.put(url=api_url, json=payload)
@@ -418,7 +421,7 @@ class DRACOONUsers:
             await self.dracoon.handle_http_error(err=e, raise_on_err=raise_on_err)
 
         self.logger.info("Updated user attributes.")
-        return UserData(**res.json())
+        return None
 
     def make_custom_user_attribute(self, key: str, value: str) -> AttributeEntry:
         """ make a custom user attribute required for update_user_attributes() """
